This crate contains kube-rs compatible bindings for Kubernetes custom resources for the datadoghq.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
datadoghq.com/v1alpha1
DatadogAgentDatadogMetricDatadogMonitorDatadogSLO
datadoghq.com/v2alpha1
DatadogAgent