pub struct DatadogAgentStatusRemoteConfigConfigurationFeaturesExternalMetricsServer {
pub enabled: Option<bool>,
pub endpoint: Option<DatadogAgentStatusRemoteConfigConfigurationFeaturesExternalMetricsServerEndpoint>,
pub port: Option<i32>,
pub register_api_service: Option<bool>,
pub use_datadog_metrics: Option<bool>,
pub wpa_controller: Option<bool>,
}Expand description
ExternalMetricsServer configuration.
Fields
enabled: Option<bool>Enabled enables the External Metrics Server. Default: false
endpoint: Option<DatadogAgentStatusRemoteConfigConfigurationFeaturesExternalMetricsServerEndpoint>Override the API endpoint for the External Metrics Server. URL Default: “https://app.datadoghq.com".
port: Option<i32>Port specifies the metricsProvider External Metrics Server service port. Default: 8443
register_api_service: Option<bool>RegisterAPIService registers the External Metrics endpoint as an APIService Default: true
use_datadog_metrics: Option<bool>UseDatadogMetrics enables usage of the DatadogMetrics CRD (allowing one to scale on arbitrary Datadog metric queries). Default: true
wpa_controller: Option<bool>WPAController enables the informer and controller of the Watermark Pod Autoscaler. NOTE: The Watermark Pod Autoscaler controller needs to be installed. See also: https://github.com/DataDog/watermarkpodautoscaler. Default: false